# BatchUpdateDocumentRequest

Request message for BatchUpdateDocument.

**Type:** object

## Properties

- **requests** (array of [Request](request.md)): A list of updates to apply to the document.
- **writeControl** ([WriteControl](writecontrol.md)): Provides control over how write requests are executed.
